==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/resourcesearch/requests/SearchResourcesRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.resourcesearch.requests;

import com.oracle.bmc.resourcesearch.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/3.40.0/resourcesearch/SearchResourcesExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use SearchResourcesRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20180409")
public class SearchResourcesRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.resourcesearch.model.SearchDetails> {

    /**
     * Request parameters that describe query criteria. For more information, see {@link
     * #searchDetails(SearchDetailsRequest) searchDetails}.
     */
    private com.oracle.bmc.resourcesearch.model.SearchDetails searchDetails;

    /**
     * Request parameters that describe query criteria. For more information, see {@link
     * #searchDetails(SearchDetailsRequest) searchDetails}.
     */
    public com.oracle.bmc.resourcesearch.model.SearchDetails getSearchDetails() {
        return searchDetails;
    }
    /** The maximum number of items to return. The value must be between 1 and 1000. */
    private Integer limit;

    /** The maximum number of items to return. The value must be between 1 and 1000. */
    public Integer getLimit() {
        return limit;
    }
    /** The page at which to start retrieving results. */
    private String page;

    /** The page at which to start retrieving results. */
    public String getPage() {
        return page;
    }
    /**
     * The tenancy ID, which can be used to specify a different tenancy (for cross-tenancy
     * authorization) when searching for resources in a different tenancy.
     */
    private String tenantId;

    /**
     * The tenancy ID, which can be used to specify a different tenancy (for cross-tenancy
     * authorization) when searching for resources in a different tenancy.
     */
    public String getTenantId() {
        return tenantId;
    }
    /**
     * The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the complete request ID.
     */
    private String opcRequestId;

    /**
     * The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the complete request ID.
     */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.resourcesearch.model.SearchDetails getBody$() {
        return searchDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    SearchResourcesRequest, com.oracle.bmc.resourcesearch.model.SearchDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /**
         * Request parameters that describe query criteria. For more information, see {@link
         * #searchDetails(SearchDetailsRequest) searchDetails}.
         */
        private com.oracle.bmc.resourcesearch.model.SearchDetails searchDetails = null;

        /**
         * Request parameters that describe query criteria. For more information, see {@link
         * #searchDetails(SearchDetailsRequest) searchDetails}.
         *
         * @param searchDetails the value to set
         * @return this builder instance
         */
        public Builder searchDetails(
                com.oracle.bmc.resourcesearch.model.SearchDetails searchDetails) {
            this.searchDetails = searchDetails;
            return this;
        }

        /** The maximum number of items to return. The value must be between 1 and 1000. */
        private Integer limit = null;

        /**
         * The maximum number of items to return. The value must be between 1 and 1000.
         *
         * @param limit the value to set
         * @return this builder instance
         */
        public Builder limit(Integer limit) {
            this.limit = limit;
            return this;
        }

        /** The page at which to start retrieving results. */
        private String page = null;

        /**
         * The page at which to start retrieving results.
         *
         * @param page the value to set
         * @return this builder instance
         */
        public Builder page(String page) {
            this.page = page;
            return this;
        }

        /**
         * The tenancy ID, which can be used to specify a different tenancy (for cross-tenancy
         * authorization) when searching for resources in a different tenancy.
         */
        private String tenantId = null;

        /**
         * The tenancy ID, which can be used to specify a different tenancy (for cross-tenancy
         * authorization) when searching for resources in a different tenancy.
         *
         * @param tenantId the value to set
         * @return this builder instance
         */
        public Builder tenantId(String tenantId) {
            this.tenantId = tenantId;
            return this;
        }

        /**
         * The unique Oracle-assigned identifier for the request. If you need to contact Oracle
         * about a particular request, please provide the complete request ID.
         */
        private String opcRequestId = null;

        /**
         * The unique Oracle-assigned identifier for the request. If you need to contact Oracle
         * about a particular request, please provide the complete request ID.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(SearchResourcesRequest o) {
            searchDetails(o.getSearchDetails());
            limit(o.getLimit());
            page(o.getPage());
            tenantId(o.getTenantId());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of SearchResourcesRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of SearchResourcesRequest
         */
        public SearchResourcesRequest build() {
            SearchResourcesRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(com.oracle.bmc.resourcesearch.model.SearchDetails body) {
            searchDetails(body);
            return this;
        }

        /**
         * Build the instance of SearchResourcesRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of SearchResourcesRequest
         */
        public SearchResourcesRequest buildWithoutInvocationCallback() {
            SearchResourcesRequest request = new SearchResourcesRequest();
            request.searchDetails = searchDetails;
            request.limit = limit;
            request.page = page;
            request.tenantId = tenantId;
            request.opcRequestId = opcRequestId;
            return request;
            // new SearchResourcesRequest(searchDetails, limit, page, tenantId, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .searchDetails(searchDetails)
                .limit(limit)
                .page(page)
                .tenantId(tenantId)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",searchDetails=").append(String.valueOf(this.searchDetails));
        sb.append(",limit=").append(String.valueOf(this.limit));
        sb.append(",page=").append(String.valueOf(this.page));
        sb.append(",tenantId=").append(String.valueOf(this.tenantId));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof SearchResourcesRequest)) {
            return false;
        }

        SearchResourcesRequest other = (SearchResourcesRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(this.searchDetails, other.searchDetails)
                && java.util.Objects.equals(this.limit, other.limit)
                && java.util.Objects.equals(this.page, other.page)
                && java.util.Objects.equals(this.tenantId, other.tenantId)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.searchDetails == null ? 43 : this.searchDetails.hashCode());
        result = (result * PRIME) + (this.limit == null ? 43 : this.limit.hashCode());
        result = (result * PRIME) + (this.page == null ? 43 : this.page.hashCode());
        result = (result * PRIME) + (this.tenantId == null ? 43 : this.tenantId.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/resourcesearch/requests/SearchResourcesRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.resourcesearch.requests;

import com.oracle.bmc.resourcesearch.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/latest/resourcesearch/SearchResourcesExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use SearchResourcesRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20180409")
public class SearchResourcesRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.resourcesearch.model.SearchDetails> {

    /**
     * Request parameters that describe query criteria. For more information, see {@link
     * #searchDetails(SearchDetailsRequest) searchDetails}.
     */
    private com.oracle.bmc.resourcesearch.model.SearchDetails searchDetails;

    /**
     * Request parameters that describe query criteria. For more information, see {@link
     * #searchDetails(SearchDetailsRequest) searchDetails}.
     */
    public com.oracle.bmc.resourcesearch.model.SearchDetails getSearchDetails() {
        return searchDetails;
    }
    /** The maximum number of items to return. The value must be between 1 and 1000. */
    private Integer limit;

    /** The maximum number of items to return. The value must be between 1 and 1000. */
    public Integer getLimit() {
        return limit;
    }
    /** The page at which to start retrieving results. */
    private String page;

    /** The page at which to start retrieving results. */
    public String getPage() {
        return page;
    }
    /**
     * The tenancy ID, which can be used to specify a different tenancy (for cross-tenancy
     * authorization) when searching for resources in a different tenancy.
     */
    private String tenantId;

    /**
     * The tenancy ID, which can be used to specify a different tenancy (for cross-tenancy
     * authorization) when searching for resources in a different tenancy.
     */
    public String getTenantId() {
        return tenantId;
    }
    /**
     * The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the complete request ID.
     */
    private String opcRequestId;

    /**
     * The unique Oracle-assigned identifier for the request. If you need to contact Oracle about a
     * particular request, please provide the complete request ID.
     */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.resourcesearch.model.SearchDetails getBody$() {
        return searchDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    SearchResourcesRequest, com.oracle.bmc.resourcesearch.model.SearchDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /**
         * Request parameters that describe query criteria. For more information, see {@link
         * #searchDetails(SearchDetailsRequest) searchDetails}.
         */
        private com.oracle.bmc.resourcesearch.model.SearchDetails searchDetails = null;

        /**
         * Request parameters that describe query criteria. For more information, see {@link
         * #searchDetails(SearchDetailsRequest) searchDetails}.
         *
         * @param searchDetails the value to set
         * @return this builder instance
         */
        public Builder searchDetails(
                com.oracle.bmc.resourcesearch.model.SearchDetails searchDetails) {
            this.searchDetails = searchDetails;
            return this;
        }

        /** The maximum number of items to return. The value must be between 1 and 1000. */
        private Integer limit = null;

        /**
         * The maximum number of items to return. The value must be between 1 and 1000.
         *
         * @param limit the value to set
         * @return this builder instance
         */
        public Builder limit(Integer limit) {
            this.limit = limit;
            return this;
        }

        /** The page at which to start retrieving results. */
        private String page = null;

        /**
         * The page at which to start retrieving results.
         *
         * @param page the value to set
         * @return this builder instance
         */
        public Builder page(String page) {
            this.page = page;
            return this;
        }

        /**
         * The tenancy ID, which can be used to specify a different tenancy (for cross-tenancy
         * authorization) when searching for resources in a different tenancy.
         */
        private String tenantId = null;

        /**
         * The tenancy ID, which can be used to specify a different tenancy (for cross-tenancy
         * authorization) when searching for resources in a different tenancy.
         *
         * @param tenantId the value to set
         * @return this builder instance
         */
        public Builder tenantId(String tenantId) {
            this.tenantId = tenantId;
            return this;
        }

        /**
         * The unique Oracle-assigned identifier for the request. If you need to contact Oracle
         * about a particular request, please provide the complete request ID.
         */
        private String opcRequestId = null;

        /**
         * The unique Oracle-assigned identifier for the request. If you need to contact Oracle
         * about a particular request, please provide the complete request ID.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(SearchResourcesRequest o) {
            searchDetails(o.getSearchDetails());
            limit(o.getLimit());
            page(o.getPage());
            tenantId(o.getTenantId());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of SearchResourcesRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of SearchResourcesRequest
         */
        public SearchResourcesRequest build() {
            SearchResourcesRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(com.oracle.bmc.resourcesearch.model.SearchDetails body) {
            searchDetails(body);
            return this;
        }

        /**
         * Build the instance of SearchResourcesRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of SearchResourcesRequest
         */
        public SearchResourcesRequest buildWithoutInvocationCallback() {
            SearchResourcesRequest request = new SearchResourcesRequest();
            request.searchDetails = searchDetails;
            request.limit = limit;
            request.page = page;
            request.tenantId = tenantId;
            request.opcRequestId = opcRequestId;
            return request;
            // new SearchResourcesRequest(searchDetails, limit, page, tenantId, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .searchDetails(searchDetails)
                .limit(limit)
                .page(page)
                .tenantId(tenantId)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",searchDetails=").append(String.valueOf(this.searchDetails));
        sb.append(",limit=").append(String.valueOf(this.limit));
        sb.append(",page=").append(String.valueOf(this.page));
        sb.append(",tenantId=").append(String.valueOf(this.tenantId));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof SearchResourcesRequest)) {
            return false;
        }

        SearchResourcesRequest other = (SearchResourcesRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(this.searchDetails, other.searchDetails)
                && java.util.Objects.equals(this.limit, other.limit)
                && java.util.Objects.equals(this.page, other.page)
                && java.util.Objects.equals(this.tenantId, other.tenantId)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.searchDetails == null ? 43 : this.searchDetails.hashCode());
        result = (result * PRIME) + (this.limit == null ? 43 : this.limit.hashCode());
        result = (result * PRIME) + (this.page == null ? 43 : this.page.hashCode());
        result = (result * PRIME) + (this.tenantId == null ? 43 : this.tenantId.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}
